@@ -24,7 +24,7 @@ from json import JSONDecodeError
 from typing import Any, Dict, Final, List, Tuple
 
 from load_shedding.providers import (
-    Area, Provider, ProviderError, Stage, StageError, datetime_to_isoformat, isoformat_to_datetime
+    Area, Provider, ProviderError, Stage, StageError, datetime_to_isoformat, isoformat_to_datetime, citypower
 )
 
 logging.basicConfig(
@@ -60,6 +60,15 @@ def get_stage(provider: Provider) -> Stage:
     return stage
 
 
+def get_stage_forecast(provider: Provider) -> List:
+    try:
+        provider = citypower.CityPower()
+        stage_forecast = provider.get_stage_forecast()
+    except Exception as e:
+        raise ProviderError(f"Unable to get stage forecast from {provider.name}.") from e
+    return stage_forecast
+
+
 def get_schedule(provider: Provider, area: Area, stage: Stage = None, cached: bool = True) -> List[Tuple]:
     try:
         os.makedirs('.cache')
