@@ -14,7 +14,6 @@
 #      You should have received a copy of the GNU General Public License
 #      along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
-from datetime import timezone, datetime, timedelta
 from typing import List, Tuple
 
 from load_shedding.providers.eskom import Eskom
@@ -52,7 +51,7 @@ class CoCT(eskom.Eskom):
 
     def get_schedule(self, area: Area, stage: Stage) -> List[Tuple]:
         try:
-            schedule = coct.get_schedule(area, stage)
+            schedule = coct.get_schedule(coct.Area(area.id), stage)
         except Exception as e:
             raise ProviderError(e)
         else:
